@@ -28,10 +28,6 @@
 # SOFTWARE.
 # ==============================================================================
 
-from .mars import NetMsgHead, NetMsg
-
-from .session import Session, SessionServer
-
 from .certificate import CASubject, CAValidity, CAData, CertificateAuthority
 from .station import ServiceProvider, Station
 
@@ -39,12 +35,6 @@ from .robot import Robot
 
 __all__ = [
 
-    # Data packing
-    'NetMsgHead', 'NetMsg',
-
-    # Session
-    'Session', 'SessionServer',
-
     # CA
     'CASubject', 'CAValidity', 'CAData', 'CertificateAuthority',
 
